@@ -443,6 +443,15 @@ function isEllipseEntity(obj) {
     return isOfType(obj, REllipseEntity) || isOfType(obj, REllipseEntityPointer);
 }
 
+/**
+ * Checks if the given object is an ellipse entity and represents an ellipse arc (not a full ellipse).
+ *
+ * \return true if the given object is an ellipse arc entity (REllipseEntity).
+ */
+function isEllipseArcEntity(obj) {
+    return (isOfType(obj, REllipseEntity) || isOfType(obj, REllipseEntityPointer)) && !obj.isFullEllipse();
+}
+
 /**
  * Checks if the given object is an ellipse entity and represents a full ellipse.
  *
@@ -969,6 +978,8 @@ function entityTypeToString(type, plural) {
         return plural ? qsTr("Linetypes") : qsTr("Linetype");
     case RS.ObjectView:
         return plural ? qsTr("Views") : qsTr("View");
+    case RS.ObjectDimStyle:
+        return plural ? qsTr("Dimension Styles") : qsTr("Dimension Style");
 
     case RS.EntityAll:
         return plural ? qsTr("Entities") : qsTr("Entity");
@@ -1505,6 +1516,23 @@ Array.prototype.containsIgnoreCase = function(obj) {
     return this.contains(obj, function(a,b) { return a.toUpperCase()===b.toUpperCase(); });
 };
 
+/**
+ * \return True if this array contains all items of the given array.
+ */
+Array.prototype.containsAll = function(obj) {
+    if (obj.length>this.length) {
+        return false;
+    }
+
+    for (var i=0; i<obj.length; i++) {
+        if (this.indexOf(obj[i])<0) {
+            return false;
+        }
+    }
+
+    return true;
+};
+
 /**
  * \return Array with all elements of this array that are not also
  * in the given array (subtract).
@@ -1630,6 +1658,42 @@ Array.alphaNumericalSorter = function(a, b) {
     return RS.compareAlphanumerical(a, b);
 };
 
+Array.prototype.filter = function(func, thisArg) {
+    if ( ! ((typeof func === 'Function' || typeof func === 'function') && this) )
+        throw new TypeError();
+
+    var len = this.length >>> 0,
+        res = new Array(len), // preallocate array
+        t = this, c = 0, i = -1;
+
+    var kValue;
+    if (thisArg === undefined){
+      while (++i !== len){
+        // checks to see if the key was set
+        if (i in this){
+          kValue = t[i]; // in case t is changed in callback
+          if (func(t[i], i, t)){
+            res[c++] = kValue;
+          }
+        }
+      }
+    }
+    else{
+      while (++i !== len){
+        // checks to see if the key was set
+        if (i in this){
+          kValue = t[i];
+          if (func.call(thisArg, t[i], i, t)){
+            res[c++] = kValue;
+          }
+        }
+      }
+    }
+
+    res.length = c; // shrink down array to proper size
+    return res;
+};
+
 /**
  * Sorts this array with string items (case insensitive)
  */
@@ -2430,7 +2494,7 @@ function addActionsToWidgets() {
     */
 
     var actions = RGuiAction.getActions();
-    var widgetTypes = ["Menu", "ToolBar", "MatrixPanel", "Panel"];
+    var widgetTypes = ["Menu", "ToolBar", "MatrixPanel", "Panel", "UserToolBar1", "UserToolBar2"];
     for (var c=0; c<actions.length; ++c) {
         var a = actions[c];
         if (a.icon.isNull() && !a.isIconDisabled()) {
@@ -2448,6 +2512,7 @@ function addActionsToWidgets() {
 
             var visibility = true;
             if (wn[0]==="!") {
+                // action not visible by default in this widget:
                 visibility = false;
                 wn = wn.substring(1);
             }
@@ -2654,15 +2719,15 @@ function autoIconPath(path) {
 }
 
 function applyTheme() {
+    var systemId = RS.getSystemId();
     var theme = RSettings.getValue("Theme/ThemeName", undefined);
-    if (!isNull(theme)) {
+    if (systemId!=="osx" && !isNull(theme)) {
         var path = "themes/" + theme + "/";
 
         qApp.styleSheet = "";
 
         // load stylesheet.css, stylesheet_[win|macos|linux].css:
         var found = false;
-        var systemId = RS.getSystemId();
         if (systemId==="osx") systemId = "macos";
 
         var postfixes = ["", "_" + systemId];
